import { NodeOrString, NodeFragmentOrString, GenericObject } from "./interfaces";

interface DomConstruct {

    /**
     * instantiates an HTML fragment returning the corresponding DOM.
     */
    toDom(frag: string, doc?: Document): DocumentFragment | Node;

    /**
     * Attempt to insert node into the DOM, choosing from various positioning options.
     * Returns the first argument resolved to a DOM node.
     */
    place(node: NodeFragmentOrString, refNode: NodeOrString, position?: string /* PosString */ | number): HTMLElement;

    /**
     * Create an element, allowing for optional attribute decoration
     * and placement.
     */
    create(tag: NodeOrString, attrs?: GenericObject, refNode?: NodeOrString, pos?: string /* PosString */ | number): HTMLElement;

    /**
     * safely removes all children of the node.
     */
    empty(node: NodeOrString): void;

    /**
     * Removes a node from its parent, clobbering it and all of its
     * children.
     */
    destroy(node: NodeOrString): void;
}

declare const domConstruct: DomConstruct;
export = domConstruct;
